.. _api:

API
===

This page contains auto-generated documentation from the bidict source code.

bidict
------

.. automodule:: bidict
    :members:
    :special-members:
    :exclude-members: __dict__,__weakref__
    :private-members:

bidict.util
-----------

.. automodule:: bidict.util
    :members:

bidict.compat
-------------

.. automodule:: bidict.compat
    :members:
